@@ -1,13 +1,11 @@
-from .convert.xml import convert_to_xml
 from .convert.xlsx import convert_to_xlsx, write_workbook
 from .convert.csv import convert_to_csv
 from .convert.json import convert_to_json
 from .services.services import Services
 
 
-__version__ = "0.3.25"
+__version__ = "0.3.27"
 __all__ = [
-    "convert_to_xml",
     "convert_to_csv",
     "convert_to_xlsx",
     "convert_to_json",
