@@ -3,7 +3,7 @@ import os
 import click
 import toml
 
-from .commands import to_csv, to_xml, to_xlsx, to_json, config
+from .commands import to_csv, to_xlsx, to_json, config
 from .commons.endpoints import default_endpoints
 from . import __version__
 
@@ -105,7 +105,6 @@ def main(ctx, config_file, endpoint_env, username, password, extractor, header):
         ctx.obj["config"]["endpoints"]["extractor"] = extractor
 
 
-main.add_command(to_xml.to_xml)
 main.add_command(to_csv.to_csv)
 main.add_command(to_xlsx.to_xlsx)
 main.add_command(to_json.to_json)
