@@ -209,9 +209,12 @@ def structure_sheets(response: dict, header_sheetname="header"):
 
 def get_output_path(input_path, output_path, extension="xlsx"):
     if not output_path:
-        output_path = (
-            f"{os.path.normpath(input_path).split(os.path.sep)[-1]}.{extension}"
-        )
+        if input_path == ".":
+            output_path = f"hycli.{extension}"
+        else:
+            output_path = (
+                f"{os.path.normpath(input_path).split(os.path.sep)[-1]}.{extension}"
+            )
     else:
         output_path = f"{os.path.join(os.getcwd(), output_path)}"
         if not os.path.isdir(os.path.sep.join(output_path.split(os.path.sep)[:-1])):
