@@ -1,3 +1,4 @@
+import os
 import json
 
 from concurrent.futures import ThreadPoolExecutor, as_completed
@@ -8,19 +9,22 @@ from ..services.requests import extract_invoice
 from .commons import read_pdf, get_filenames
 
 
-def convert_to_json(path, extractor_endpoint, token, workers, headers):
+def convert_to_json(
+    input_path, services, workers, output_path: str = None,
+):
     # Todo: add single invoice path besides dir
-    files = get_filenames(path)
+    files = get_filenames(input_path)
+    skipped_files = []
 
     with ThreadPoolExecutor(max_workers=workers) as exe:
         jobs = {
             exe.submit(
                 extract_invoice,
                 read_pdf(file_path),
-                extractor_endpoint,
+                services.extractor_endpoint,
                 file_extension,
-                token,
-                headers,
+                services.get_token,
+                services.headers,
             ): file_path
             for file_path, file_extension in files.items()
         }
@@ -32,9 +36,18 @@ def convert_to_json(path, extractor_endpoint, token, workers, headers):
                     response = future.result(timeout=300)
 
                 except Exception as e:
-                    print(f"Error: {e}")
+                    skipped_files.append((file_name, e))
+                    continue
 
-                with open(file_name.split(".")[0] + ".json", "w") as f:
+                file_path = f"{file_name.split('.')[0]}.json"
+
+                if output_path:
+                    file_path = os.path.join(output_path, file_path)
+                    os.makedirs(os.path.dirname(file_path), exist_ok=True)
+
+                with open(file_path, "w") as f:
                     json.dump(response, f)
 
                 bar.update(1)
+
+    return skipped_files
