@@ -51,22 +51,15 @@ def convert_to_xlsx(
 
 
 def write_workbook(
-    output_path: str,
-    sheets: List[dict],
-    vat_validation=None,
-    validation: bool = False,
-    progress_reporter: object = None,
+    output_path: str, sheets: List[dict], vat_validation=None, validation: bool = False,
 ):
     # Init workbook/sheets
     workbook = xlsxwriter.Workbook(output_path)
 
-    # Add progress counter
-    if progress_reporter:
-        progress_reporter.max += sum([len(*sheet.values()) for sheet in sheets])
-
     # Styling
-    header = workbook.add_format({"bold": True})
-    probability_format = [
+    header_format = workbook.add_format({"bold": True})
+    number_format = workbook.add_format({"num_format": "0.00"})
+    probability_formats = [
         workbook.add_format({"bold": True, "bg_color": color})
         for color in RED_TO_GREEN_GRADIENT
     ]
@@ -76,10 +69,10 @@ def write_workbook(
         write_sheet(
             workbook.get_worksheet_by_name(sheet),
             structure_sheet(sheets[sheet]),
-            header,
-            probability_format,
             validation,
-            progress_reporter,
+            header_format,
+            number_format,
+            probability_formats,
         )
 
     if vat_validation:
@@ -91,10 +84,10 @@ def write_workbook(
 def write_sheet(
     worksheet,
     records: list,
-    bold_header,
-    red_to_green_formats: list,
     validation: bool,
-    progress_reporter: object = None,
+    header_format,
+    number_format,
+    probability_formats: list,
 ):
     """Write items to workbook sheet.
 
@@ -108,23 +101,24 @@ def write_sheet(
     for idx, row in enumerate(records):
         count = 0
         for key, value in row.copy().items():
-            worksheet.write(0, count, key, bold_header)
+            worksheet.write(0, count, key, header_format)
             if not isinstance(value, tuple):
                 records[idx][key] = (value, None, None)
 
             column_value, probability, validation_errors = records[idx][key]
+            value_format = number_format if isinstance(column_value, float) else None
 
             if pd.notna(probability):
-                color_idx = int((len(red_to_green_formats) - 1) * probability)
-                color = red_to_green_formats[color_idx]
+                color_idx = int((len(probability_formats) - 1) * probability)
+                color = probability_formats[color_idx]
                 worksheet.write(idx + 1, count, column_value, color)
             else:
-                worksheet.write(idx + 1, count, column_value)
+                worksheet.write(idx + 1, count, column_value, value_format)
 
             if validation and key not in ["file_name", "error_message", "row_number"]:
                 validation_errors = validation_errors if validation_errors else 0
                 count += 1
-                worksheet.write(0, count, f"{key}ValidationErrors", bold_header)
+                worksheet.write(0, count, f"{key}ValidationErrors", header_format)
                 if validation_errors == 0:
                     worksheet.write(idx + 1, count, validation_errors)
                 else:
@@ -133,9 +127,6 @@ def write_sheet(
 
             count += 1
 
-        if progress_reporter:
-            progress_reporter.current += 1
-
     for i, width in enumerate(get_col_widths(pd.DataFrame.from_records(records))):
         worksheet.set_column(i, i, width)
 
