@@ -28,7 +28,7 @@ def extract_invoice(
     extractor_endpoint,
     content_type,
     get_token: Callable[[], str] = None,
-    params: Dict = None,
+    params: Dict = {},
     timeout: int = 1800,
 ):
     """ Request invoice extractor """
